@@ -22,29 +22,29 @@
 class MediaManager;
 class MediaSession : public QObject
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	MediaSession(MediaManager *mediaManager, const QString& codecName);
-	~MediaSession();
+    MediaSession(MediaManager *mediaManager, const QString &codecName);
+    ~MediaSession();
 
-	void setSamplingRate(int sr);
-	void setQuality(int q);
-	bool start();
-	void write(const QByteArray& sData);
-	QByteArray read() const;
-	int timeStamp();
+    void setSamplingRate(int sr);
+    void setQuality(int q);
+    bool start();
+    void write(const QByteArray &sData);
+    QByteArray read() const;
+    int timeStamp();
 
-public slots:
-	void slotReadyRead();
-	void slotEncoded();
-	void slotDecoded();
+public Q_SLOTS:
+    void slotReadyRead();
+    void slotEncoded();
+    void slotDecoded();
 
-signals:
-	void readyRead();
+Q_SIGNALS:
+    void readyRead();
 
 private:
-	class Private;
-	Private * const d;
+    class Private;
+    Private *const d;
 };
 
 #endif
